jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container Adapter.java,1.2,1.3 Container.java,1.6,1.7 Factory.java,1.3,1.4 IllegalSelectorException.java,1.4,1.5 JicarillaClassNotFoundException.java,1.4,1.5 JicarillaException.java,1.5,1.6 JicarillaIllegalAccessException.java,1.4,1.5 JicarillaIllegalStateException.java,1.1,1.2 JicarillaInstantiationException.java,1.4,1.5 JicarillaInvocationTargetException.java,1.4,1.5 KeyRelayingContainer.java,1.5,1.6

Leo Simons <[email protected]>
Newsgroups gmane.comp.java.jicarilla.cvs
Message-ID <[email protected]>
Update of /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv24005/platform/container/api/src/java/org/jicarilla/container

Modified Files:
	Adapter.java Container.java Factory.java 
	IllegalSelectorException.java 
	JicarillaClassNotFoundException.java JicarillaException.java 
	JicarillaIllegalAccessException.java 
	JicarillaIllegalStateException.java 
	JicarillaInstantiationException.java 
	JicarillaInvocationTargetException.java 
	KeyRelayingContainer.java 
Log Message:
s/o.j.f/o.j.l/

Index: JicarillaIllegalAccessException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/JicarillaIllegalAccessException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- JicarillaIllegalAccessException.java	8 Jan 2004 16:01:08 -0000	1.4
+++ JicarillaIllegalAccessException.java	23 Mar 2004 13:37:51 -0000	1.5
@@ -29,7 +29,7 @@
  * A {@link JicarillaException} that is thrown by containers, adapters,
  * factories or resolvers if they have a problem accessing some external
  * resource and are thus unable to create or provide an instance. The
- * {@link org.jicarilla.framework.CascadingRuntimeException#getCause()}
+ * {@link org.jicarilla.lang.CascadingRuntimeException#getCause()}
  * method will normally return the {@link IllegalAccessException} that caused
  * the problem.
  *

Index: JicarillaIllegalStateException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/JicarillaIllegalStateException.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- JicarillaIllegalStateException.java	10 Jan 2004 10:49:50 -0000	1.1
+++ JicarillaIllegalStateException.java	23 Mar 2004 13:37:51 -0000	1.2
@@ -29,7 +29,7 @@
  * A {@link JicarillaException} that is thrown by containers, adapters,
  * factories or resolvers if a method is called on them while they are
  * not ready for it. The
- * {@link org.jicarilla.framework.CascadingRuntimeException#getCause()}
+ * {@link org.jicarilla.lang.CascadingRuntimeException#getCause()}
  * method will normally return the {@link IllegalStateException} that caused
  * the problem.
  *

Index: JicarillaInvocationTargetException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/JicarillaInvocationTargetException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- JicarillaInvocationTargetException.java	8 Jan 2004 16:01:08 -0000	1.4
+++ JicarillaInvocationTargetException.java	23 Mar 2004 13:37:51 -0000	1.5
@@ -29,7 +29,7 @@
  * A {@link JicarillaException} that is thrown by containers, adapters,
  * factories or resolvers if they have has a problem invoking some external
  * resource and are thus unable to create or return an instance. The
- * {@link org.jicarilla.framework.CascadingRuntimeException#getCause()}
+ * {@link org.jicarilla.lang.CascadingRuntimeException#getCause()}
  * method will normally return the
  * {@link java.lang.reflect.InvocationTargetException} that caused the problem.
  *

Index: Adapter.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/Adapter.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- Adapter.java	8 Jan 2004 14:51:59 -0000	1.2
+++ Adapter.java	23 Mar 2004 13:37:51 -0000	1.3
@@ -58,7 +58,7 @@
  * mechanism inside the container. In the case of the {@link Container}
  * interface. that selection mechanism is either a key (similar to the keys
  * used in {@link java.util.Map maps} or an instance of a
- * {@link org.jicarilla.framework.Selector}.</p>
+ * {@link org.jicarilla.lang.Selector}.</p>
  *
  * <p>Note that it is usually possible to use an adapter without using a
  * container. When doing so, observe these contracts:</p>

Index: Container.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/Container.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- Container.java	8 Jan 2004 16:01:08 -0000	1.6
+++ Container.java	23 Mar 2004 13:37:51 -0000	1.7
@@ -25,7 +25,7 @@
 ==================================================================== */
 package org.jicarilla.container;
 
-import org.jicarilla.framework.Selector;
+import org.jicarilla.lang.Selector;
 
 /**
  * A container holds {@link Adapter adapters}, and provides a
@@ -57,7 +57,7 @@
      * @throws IllegalSelectorException if the provided selector is not
      *     supported by this container (if it is null, for example, or
      *     if it is not a
-     *     {@link org.jicarilla.framework.CriterionExposingSelector} and
+     *     {@link org.jicarilla.lang.CriterionExposingSelector} and
      *     the container requires it to be).
      * @throws IllegalAdapterException if the provided adapter is not
      *     supported by this container (if it is null, for example, or

Index: JicarillaClassNotFoundException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/JicarillaClassNotFoundException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- JicarillaClassNotFoundException.java	10 Jan 2004 16:04:50 -0000	1.4
+++ JicarillaClassNotFoundException.java	23 Mar 2004 13:37:51 -0000	1.5
@@ -28,7 +28,7 @@
 /**
  * A {@link JicarillaException} that is thrown by containers, adapters,
  * factories or resolvers if an attempt to load a class fails. The
- * {@link org.jicarilla.framework.CascadingRuntimeException#getCause()}
+ * {@link org.jicarilla.lang.CascadingRuntimeException#getCause()}
  * method will normally return the {@link ClassNotFoundException} that caused
  * the problem.
  *

Index: KeyRelayingContainer.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/KeyRelayingContainer.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- KeyRelayingContainer.java	8 Jan 2004 16:01:08 -0000	1.5
+++ KeyRelayingContainer.java	23 Mar 2004 13:37:51 -0000	1.6
@@ -25,7 +25,7 @@
 ==================================================================== */
 package org.jicarilla.container;
 
-import org.jicarilla.framework.Selector;
+import org.jicarilla.lang.Selector;
 
 /**
  * A variant on the {@link Container} interface that passes on criterions
@@ -60,7 +60,7 @@
      * @throws IllegalSelectorException if the provided selector is not
      *     supported by this container (if it is null, for example, or
      *     if it is not a
-     *     {@link org.jicarilla.framework.CriterionExposingSelector} and
+     *     {@link org.jicarilla.lang.CriterionExposingSelector} and
      *     the container requires it to be).
      * @throws IllegalAdapterException if the provided adapter is not
      *     supported by this container (if it is null, for example, or

Index: JicarillaInstantiationException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/JicarillaInstantiationException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- JicarillaInstantiationException.java	8 Jan 2004 16:01:08 -0000	1.4
+++ JicarillaInstantiationException.java	23 Mar 2004 13:37:51 -0000	1.5
@@ -28,7 +28,7 @@
 /**
  * A {@link JicarillaException} that is thrown by containers, adapters,
  * factories or resolvers if they have has a problem creating an instance. The
- * {@link org.jicarilla.framework.CascadingRuntimeException#getCause()}
+ * {@link org.jicarilla.lang.CascadingRuntimeException#getCause()}
  * method will normally return the {@link InstantiationException} that caused
  * the problem.
  *

Index: Factory.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/Factory.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- Factory.java	26 Feb 2004 16:51:56 -0000	1.3
+++ Factory.java	23 Mar 2004 13:37:51 -0000	1.4
@@ -33,7 +33,7 @@
  * <p>Note that while the interfaces for adapters and factories are nearly the
  * same, the two don't do quite the same thing. Whereas an adapter is intended
  * to be associated with a {@link Container} through the use of a
- * {@link org.jicarilla.framework.Selector} and is not required to always
+ * {@link org.jicarilla.lang.Selector} and is not required to always
  * return a new instance from its {@link Adapter#getInstance()} method, the
  * factory must always return a <i>new</i> instance on every call to its
  * {@link #newInstance()} method, and is never directly associated with a

Index: JicarillaException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/JicarillaException.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- JicarillaException.java	11 Jan 2004 11:56:24 -0000	1.5
+++ JicarillaException.java	23 Mar 2004 13:37:51 -0000	1.6
@@ -25,7 +25,7 @@
 ==================================================================== */
 package org.jicarilla.container;
 
-import org.jicarilla.framework.CascadingRuntimeException;
+import org.jicarilla.lang.CascadingRuntimeException;
 
 /**
  * <p>The root exception for all of the more specific errors that are thrown by



-------------------------------------------------------
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
Index: IllegalSelectorException.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/container/api/src/java/org/jicarilla/container/IllegalSelectorException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- IllegalSelectorException.java	10 Jan 2004 16:04:50 -0000	1.4
+++ IllegalSelectorException.java	23 Mar 2004 13:37:51 -0000	1.5
@@ -25,13 +25,13 @@
 ==================================================================== */
 package org.jicarilla.container;
 
-import org.jicarilla.framework.Selector;
+import org.jicarilla.lang.Selector;
 
 /**
  * A {@link JicarillaException} that is thrown by a {@link Container} if a
  * provided selector is not supported by that container (if it is null, for
  * example, or if it is not a
  * {@link org.jicarilla.framework.CriterionExposingSelector} and the container
  * requires it to be).
  *
  * @author <a href="mail at leosimons dot com">Leo Simons</a>
@@ -25,13 +25,13 @@
  * provided selector is not supported by that container (if it is null, for
  * example, or if it is not a
- * {@link org.jicarilla.framework.CriterionExposingSelector} and the container
+ * {@link org.jicarilla.lang.CriterionExposingSelector} and the container
  * requires it to be).
  *
